import React, { FC, useState } from 'react';
import { StyledButton, StyledFlex, StyledSeparator } from '../styledComponents';
import { ButtonAppearance, Views } from '../constants';
import { AuthorizerVerifyOtp } from './AuthorizerVerifyOtp';

export const AuthorizerTOTPScanner: FC<{
  setView?: (v: Views) => void;
  onLogin?: (data: any) => void;
  email?: string;
  phone_number?: string;
  urlProps?: Record<string, any>;
  authenticator_scanner_image: string;
  authenticator_secret: string;
  authenticator_recovery_codes: string[];
}> = ({
  setView,
  onLogin,
  email,
  phone_number,
  authenticator_scanner_image,
  authenticator_secret,
  authenticator_recovery_codes,
  urlProps,
}) => {
  const [isOTPScreenVisisble, setIsOTPScreenVisisble] = useState<boolean>(
    false
  );

  const handleContinue = () => {
    setIsOTPScreenVisisble(true);
  };

  if (isOTPScreenVisisble) {
    return (
      <AuthorizerVerifyOtp
        {...{
          setView,
          onLogin,
          email,
          phone_number,
          urlProps,
        }}
        is_totp
      />
    );
  }

  return (
    <>
      <p style={{ margin: '10px 0px', fontWeight: 'bold' }}>
        Отсканируйте QR-код или введите секретный ключ в
        приложение-аутентификатор.
      </p>
      <StyledFlex justifyContent="center">
        <img
          src={`data:image/jpeg;base64,${authenticator_scanner_image}`}
          alt="сканер"
        />
      </StyledFlex>
      <p style={{ margin: '10px 0px' }}>
        Если у вас не получается отсканировать QR-код, пожалуйста, введите
        секретный ключ вручную.
      </p>
      <p style={{ margin: '10px 0px', fontWeight: 'bold' }}>
        {authenticator_secret}
      </p>
      <StyledSeparator />
      <p style={{ margin: '10px 0px' }}>
        Если вы потеряете доступ к приложению-аутентификатору, вы можете
        воспользоваться кодами восстановления ниже, чтобы вернуть доступ к
        аккаунту. Пожалуйста, храните эти коды в надежном месте и никому их не
        передавайте.
      </p>
      <ul>
        {authenticator_recovery_codes.map((code, index) => {
          return <li key={index}>{code}</li>;
        })}
      </ul>
      <StyledButton
        type="button"
        appearance={ButtonAppearance.Primary}
        onClick={handleContinue}
      >
        Продолжить
      </StyledButton>
    </>
  );
};
